pub struct OutputPattern {
pub location: ScriptLocation,
pub pattern: OutputPatternType,
pub ignore: OutputPatterns,
pub reject: OutputPatterns,
}Fields
location: ScriptLocationpattern: OutputPatternTypeignore: OutputPatternsreject: OutputPatternsImplementations
Sourceimpl OutputPattern
impl OutputPattern
pub fn new_sequence( location: ScriptLocation, patterns: Vec<OutputPattern>, ) -> Self
pub fn prepare(&self, grok: &Grok) -> Result<(), OutputPatternPrepareError>
pub fn matches( &self, context: OutputMatchContext<'_>, output: Lines, ) -> Result<Lines, OutputPatternMatchFailure>
Sourcepub fn min_matches(&self) -> usize
pub fn min_matches(&self) -> usize
The minimum number of lines this pattern will match.
Sourcepub fn max_matches(&self) -> usize
pub fn max_matches(&self) -> usize
The maximum number of lines this pattern will match (or usize::MAX if unbounded).