pub struct NicePathBuf { /* private fields */ }Implementations
Sourceimpl NicePathBuf
impl NicePathBuf
pub fn new(path: impl AsRef<Path>) -> Self
pub fn exists(&self) -> Result<bool>
pub fn join(&self, other: impl AsRef<Path>) -> Self
pub fn create_dir_all(&self) -> Result<()>
pub fn remove_dir_all(&self) -> Result<()>
pub fn parent(&self) -> Option<NicePathBuf>
pub fn cwd() -> NicePathBuf
Sourcepub fn env_string(&self) -> String
pub fn env_string(&self) -> String
Returns a string that can be used in the environment to refer to this path.
In the case where this path may be accessed via multiple routes, we will choose the shortest (ie: /tmp on macOS rather than /private/tmp).