OutputPatternType

Enum OutputPatternType 

pub enum OutputPatternType {
    End,
    None,
    Any(Box<OutputPattern>),
    Literal(String),
    Pattern(Arc<GrokPattern>),
    Repeat(Box<OutputPattern>),
    Optional(Box<OutputPattern>),
    Unordered(Vec<OutputPattern>),
    Choice(Vec<OutputPattern>),
    Sequence(Vec<OutputPattern>),
    Not(Box<OutputPattern>),
    If(IfCondition, Box<OutputPattern>),
}

Variants



End

The end of the output



None

Matches no lines of output, always succeeds



Any(Box<OutputPattern>)

Any lines, followed by a pattern.



Literal(String)

A literal string



Pattern(Arc<GrokPattern>)

A grok pattern



Repeat(Box<OutputPattern>)

A pattern that matches one or more of the given pattern



Optional(Box<OutputPattern>)

A pattern that matches zero or one of the given pattern



Unordered(Vec<OutputPattern>)

A pattern that all of its subpatterns, but in any order



Choice(Vec<OutputPattern>)

A pattern that matches one of the given patterns



Sequence(Vec<OutputPattern>)

A pattern that matches a sequence of patterns



Not(Box<OutputPattern>)

A negative look-ahead pattern



If(IfCondition, Box<OutputPattern>)

A pattern that matches a condition

Implementations

Source

impl OutputPatternType

pub fn min_matches(&self) -> usize

The minimum number of lines this pattern will match.

pub fn max_matches(&self) -> usize

The maximum number of lines this pattern will match (or usize::MAX if unbounded).

Source

impl OutputPatternType

pub fn matches<'s>( &self, location: &ScriptLocation, context: OutputMatchContext<'_>, output: Lines, ) -> Result<Lines, OutputPatternMatchFailure>